@@ -1,3 +1,5 @@
+use js_typify_gostruct::Source;
+
 fn main() -> Result<(), Vec<String>> {
     let example = r#"
     type Region struct {
@@ -5,8 +7,8 @@ fn main() -> Result<(), Vec<String>> {
     State string 
     }
     "#; // TODO: Fix bug for scenario when the closing } is not provided
-
-    let result = js_typify_gostruct::transform(example, "flow")?;
+    let source = Source::new(example);
+    let result = source.transform_to("flow")?;
     println!("{}", result);
     Ok(())
 }
